package jemmysample;

import java.awt.Component;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.logging.Level;
import java.util.logging.Logger;
import jemmysample.structure.AlbumsDialogOperator;
import org.junit.Ignore;
import org.junit.Test;
import org.netbeans.jemmy.ClassReference;
import org.netbeans.jemmy.JemmyProperties;
import org.netbeans.jemmy.operators.JComboBoxOperator;
import org.netbeans.jemmy.operators.JRadioButtonOperator;
import org.netbeans.jemmy.operators.JTextFieldOperator;
import static org.junit.Assert.*;

/**
 *
 * @author Pawel Prokop <prokop@adfinem.net>
 */
//@Ignore
public class JemmySampleTest extends CommonTest
    //implements Scenario 
{

    private static ArrayList<String> itemList = new ArrayList<String>();
    static {
        itemList.add("The Piper at the Gates of Dawn");
        itemList.add("A Saucerful of Secrets");
        itemList.add("More");
        itemList.add("Ummagumma");
        itemList.add("Atom Heart Mother");
        itemList.add("Meddle");
        itemList.add("Obscured by Clouds");
        itemList.add("The Dark Side of the Moon");
        itemList.add("Wish You Were Here");
        itemList.add("Animals");
        itemList.add("The Wall");
        itemList.add("The Final Cut");
        itemList.add("A Momentary Lapse of Reason");
        itemList.add("The Division Bell");
    }

    public JemmySampleTest() {
        try {
            new ClassReference("org.netbeans.jemmy.explorer.GUIBrowser").startApplication();
            //new JFrameOperator("GUI Browser");
        } catch (Exception ex) {
            Logger.getLogger(JemmySampleTest.class.getName()).log(Level.SEVERE, null, ex);
        }
    }



    //@Ignore
    @Test
    public void testDefaultButtonStates(){

        //try { Thread.sleep(120000); } catch (Exception e) {}

        assertTrue(application.getFixedButton().isEnabled());
        assertTrue(application.getFixedButton().isSelected());

        assertTrue(application.getCustomButton().isEnabled());
        assertFalse(application.getCustomButton().isSelected());

        assertTrue(application.getRandomButton().isEnabled());
        assertFalse(application.getRandomButton().isSelected());
    }

    //@Ignore
    @Test
    public void testRadioButtons() {
        JRadioButtonOperator btnFixed = application.getFixedButton();
        JRadioButtonOperator btnCustom = application.getCustomButton();
        JRadioButtonOperator btnRandom = application.getRandomButton();

        // push another button
        btnCustom.push();

        // check state of fixed combo
        assertFalse(application.getFixedComboBox().isEnabled());
        assertFalse(application.getFixedLabel().isEnabled());

        assertFalse(btnFixed.isSelected());
        assertFalse(btnRandom.isSelected());

        // push Fixed button
        btnFixed.push();
        assertTrue(application.getFixedComboBox().isEnabled());
        assertTrue(application.getFixedLabel().isEnabled());

        assertFalse(application.getCustomTextField().isEnabled());
        assertFalse(application.getCustomLabel().isEnabled());

        assertFalse(btnCustom.isSelected());
        assertFalse(btnRandom.isSelected());

        // pushRandomButton
        btnRandom.push();

        assertFalse(application.getFixedComboBox().isEnabled());
        assertFalse(application.getFixedLabel().isEnabled());
        assertFalse(application.getCustomTextField().isEnabled());
        assertFalse(application.getCustomLabel().isEnabled());

        assertFalse(btnCustom.isSelected());
        assertFalse(btnFixed.isSelected());
    }

    //@Ignore
    @Test
    public void testFixedButton() {
        application.getFixedButton().push();
        JComboBoxOperator cmbFixed = application.getFixedComboBox();

        for (String item : itemList) {
            cmbFixed.selectItem(item);
            assertEquals(item, cmbFixed.getSelectedItem());

            application.pushPlayButton();
            AlbumsDialogOperator albums = new AlbumsDialogOperator();

            assertEquals(item, albums.getAlbumText());

            albums.pushOK();
            assertNull(AlbumsDialogOperator.findJDialog(
                    AlbumsDialogOperator.TITLE, false, true));
        }
    }

    //@Ignore
    @Test
    public void testCustomButton() {
        //JemmyProperties.getCurrentTimeouts().setTimeout
        //        ("JTextComponentOperator.BetweenKeysTimeout", 500);
        //JemmyProperties.getCurrentTimeouts().setTimeout
        //        ("JTextComponentOperator.PushKeyTimeout", 500);


        application.getCustomButton().push();
        JTextFieldOperator txtCustom = application.getCustomTextField();

        //JemmyProperties.getCurrentTimeouts().setTimeout
        //        ("DialogWaiter.WaitDialogTimeout", 5000);
        //JDialogOperator albums = new JDialogOperator("Dialog Caption");

        for (String item : itemList) {
            txtCustom.clearText();
            txtCustom.enterText(item);
            assertEquals(item, txtCustom.getText());

            application.pushPlayButton();
            AlbumsDialogOperator albums = new AlbumsDialogOperator();

            assertEquals(item, albums.getAlbumText());

            albums.pushOK();
            assertNull(AlbumsDialogOperator.findJDialog(
                    AlbumsDialogOperator.TITLE, false, true));
        }
    }

    //@Ignore
    @Test
    public void testRandomButton() {
        application.getRandomButton().push();

        for (int i=0; i<10; i++) {
            application.pushPlayButton();

            jemmysample.structure.AlbumsDialogOperator albums =
                    new jemmysample.structure.AlbumsDialogOperator();

            assertTrue(itemList.contains(albums.getAlbumText()));

            albums.pushOK();
            assertNull(AlbumsDialogOperator.findJDialog(
                    AlbumsDialogOperator.TITLE, false, true));
        }
    }

    //@Ignore
    @Test
    public void testDumpExample() {
        try {
            Component comp = application.getMainFrame().getComponent(0);

            org.netbeans.jemmy.util.Dumper.dumpComponent(
                    comp,
                    "jemmy_example_component.xml");
        } catch (FileNotFoundException ex) {
            Logger.getLogger(JemmySampleTest.class.getName()).log(Level.SEVERE, null, ex);
        }

        //org.netbeans.jemmy.util.Dumper.dumpAll("jemmy_example.xml");
        org.netbeans.jemmy.util.PNGEncoder.captureScreen("screen.png");

    }

}